relay2slack
======

relay2slack is a tool for capturing and forwarding incoming Slack webhook events.


Installation
------------
To install relay2slack, simply:

.. code-block:: bash

    $ pip install relay2slack

To run relay2slack in the foreground:

.. code-block:: bash

    $ relay2slack

If you would like to daemonize relay2slack, refer to `docs/ <docs/>`_ for supported methods.
